--[[
	GemCensus: A gem popularity addon.
	Copyright (c) 2010 Cyprias <Cyprias@gmail.com>
	All Rights Reserved.
	Only Curse.com, WoWInterface.com & WoWace.com have permission to redistribute this software. 
	GemCensus shall not be included in a UI pack / compilation without permission. 
]]

local folder, core = ...

local LibStub = LibStub
local Debug = core.Debug
local table_insert = table.insert
local table_sort = table.sort
local print = print
local HideUIPanel = HideUIPanel
local InterfaceOptionsFrame = InterfaceOptionsFrame
local GameMenuFrame = GameMenuFrame
local CreateFrame = CreateFrame
local table_wipe = table.wipe
local echo = core.echo
local ENABLE = ENABLE
local pairs = pairs
local StaticPopup_Show = StaticPopup_Show
local L = core.L
local GENERAL = GENERAL
local DISPLAY = DISPLAY
local UnitName = UnitName


local Options = core:NewModule("MainOptions","AceConsole-3.0")

core.defaultSettings.profile = {
	inspectOnTarget = true,
	printWhenInspecting = false,
	inspectThrottle = 24,
}

function Options:OnInitialize()
	self:AddBlizzardOptions()
	self:CreateOptionsDisplay()
	
	self:RegisterChatCommand("gc", "ChatCommand")
end

_G.StaticPopupDialogs["GemCensus_DeleteData"] = {
	text = folder.."\n"..L.deleteAllData,
	button1 = OKAY,
	button2 = CANCEL,
	OnAccept = function (self)
		core.db.global.playerGems = {}
		core.db.global.playerInfo = {}
		
		echo(L.deletedAllData)
	end,
	OnHide = function (self)
		LibStub("AceConfigDialog-3.0"):Open(core.title)
	end,
	hideOnEscape = 1,
	timeout = 0,
};

function Options:CreateOptionsDisplay()
	local db = core.db
	local options = {
		type = "group",
		name = core.titleFull,
--~ 		get = function( k ) return db[k.arg] end,
--~ 		set = function( k, v ) db[k.arg] = v; end,
		
		get = function(info)
			local key = info[#info]
			return db.profile[key]
		end,
		set = function(info, v)
			local key = info[#info] 
			db.profile[key] = v
		end,
		
		
		args = {},
		plugins = {},
	}
	
	options.plugins["profiles"] = { profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(db) }

	options.args.general = {
		type = "group",
		name = GENERAL,
		order = 1,
		disabled = function(info) 
			if info.type ~= "group" then
				return not core:IsEnabled()
			end
			return false
		end,
		args = {
		
			enable = {
				type = "toggle",	order	= 1,
				name	= ENABLE,
				desc	= L.enableDesc,
				set = function(info,val) 
					if val == true then
						core:Enable()
					else
						core:Disable()
					end
				
				end,
				get = function(info) return core:IsEnabled() end,
				disabled = false,
			},
			
			inspectOnTarget = {
				type = "toggle",	order	= 5,
				name	= L.inspectOnTargetName,
				desc	= L.inspectOnTargetDesc,
			},
			
			printWhenInspecting = {
				type = "toggle",	order	= 6,
				name	= L.printWhenInspectingName,
				desc	= L.printWhenInspectingDesc,
			},
			
			inspectThrottle = {
				type = "range",	order	= 7,
				name	= L.inspectThrottleName,
				desc	= "Wait atleast * hours before inspecting someone again.",
				min 	= 1,
				max 	= 24*7,
				step	= 1,
			},
		
		
			deleteData = {
				type = "execute",	order	= 20,
				name	= L.deleteDataName,
				desc	= L.deleteDataDesc,
				func = function(info, v)
					StaticPopup_Show("GemCensus_DeleteData");
					
					LibStub("AceConfigDialog-3.0"):Close(core.title)

				end,
			},
		
		
		},
	}
	
	--Display options are provided by the Display module. If it's not loaded a button is shown to load the module.
	options.args.display = {
		type = "group",
		name = DISPLAY,
		order = 2,
		disabled = function() return not core:IsEnabled() end,
		args = {
		
			Desc = {
				type = "description",
				name = L.displayOptionsMissing,
				order = 1,
			},
			loadDisplay = {
				type = "execute",	order	= 2,
				name	= L.loadDisplayName,
				desc	= L.loadDisplayDesc,
				func = function(info, v)
					echo(L.loadingDisplayModule)
					core:LoadAddon("GemCensus_Display")
				end,
			},
		}
	}
	
	--[[
	options.args.modules = {
		type = "group",
		name = "Modules",
		order = 3,
		args = {
			test = {
				type = "execute",	order	= 11,
				name	= "Open options frame",
				desc	= "Sorry Mario, but the options are in another frame.",
				func = function(info, v)
					print("Hi")
					
				end,
			},
		}
	}
	
	local modules = {}
	for name, module in core:IterateModules() do
		if module.GetOptions then
			Debug("CreateOptionsDisplay", name)
			
			table_insert(modules, #modules+1, {name=module.name, mod=module})
		end
	end
	table_sort(modules, function(a,b) 
		if(a and b) then 
			return a.name < b.name;
		end 
	end)
	for i=1, #modules do 
		options.args.modules.args[modules[i].name] = modules[i].mod:GetOptions()
		options.args.modules.args[modules[i].name].order = i
	end
	]]
	
	
	
	
	
	local config = LibStub("AceConfig-3.0")
--~ 	local dialog = LibStub("AceConfigDialog-3.0")
	config:RegisterOptionsTable(core.title, options ) --
--~ 	coreOpts = dialog:AddToBlizOptions(core.title, core.titleFull)
	
	self.options = options
	
end


function Options:ChangeOptionsDisabled(status)
-- When addon is disabled, disable all options except the enable option.
	for subMenu, options in pairs(self.options.args) do 
		for option in pairs(options.args) do 
			if option ~= "enable" then
				options.args[option].disabled = not status
			end
		end
	end
end


local coreOpts
function Options:AddBlizzardOptions()
-- I'm going to use AceConfigDialog's window to show my options. 
-- But I still want my addon listed in Blizzard's options frame. 
-- The only thing shown in the Blizzard options frame will be a button 
-- to open AceConfigDialog's window.

	local blizOptions = {
		name = core.name,
		type = "group",
		args = {
		
			Desc = {
				type = "description",
				name = L.blizOptionsName:format(UnitName("player")),
				order = 1,
			},
			openOptionsFrame = {
				type = "execute",	order	= 2,
				name	= L.openOptionsFrameName,
				desc	= L.openOptionsFrameDesc,
				func = function(info, v)
					HideUIPanel(InterfaceOptionsFrame)
					HideUIPanel(GameMenuFrame)
					
					--If I open the AceConfigDialog window now it will close once HideUIPanel fires. 
					-- So I'm making a frame to open it on the next frame refresh.
					local f = CreateFrame("Frame")
					f:SetScript("OnUpdate", function(this, elapsed) 
						LibStub("AceConfigDialog-3.0"):Open(core.title)
						this:Hide()
						table_wipe(this)
					end)
				end,
			},
		}
	}

	local config = LibStub("AceConfig-3.0")
	local dialog = LibStub("AceConfigDialog-3.0")
	local blizName = core.title.."bliz"
	
	config:RegisterOptionsTable(blizName, blizOptions )
	coreOpts = dialog:AddToBlizOptions(blizName, core.titleFull)
end

----------------------------------------------
function Options:ChatCommand(input)	--
----------------------------------------------
--~ 	InterfaceOptionsFrame_OpenToCategory(submenuOpts) --expand the submenus.
--~ 	InterfaceOptionsFrame_OpenToCategory(coreOpts)

	if not input or input:trim() == "" then
		core:ShowDisplay()
	elseif input == "config" then
		LibStub("AceConfigDialog-3.0"):Open(core.title)
	end
end