--[[
	GemCensus: A gem popularity addon.
	Copyright (c) 2010 Cyprias <Cyprias@gmail.com>
	All Rights Reserved.
	Only Curse.com, WoWInterface.com & WoWace.com have permission to redistribute this software. 
	GemCensus shall not be included in a UI pack / compilation without permission. 
]]

local folder = "GemCensus_Display"
local core = LibStub("AceAddon-3.0"):GetAddon("GemCensus")

local Debug = core.Debug
local LibStub = LibStub
local DISPLAY = DISPLAY
local HIDE = HIDE


local display = core.display
local L = core.L

--~ print(folder.." loaded again!", display)

local mainOptions = core:GetModule("MainOptions")

function display:UpdateOptionsTable()
	self.db = core.db:RegisterNamespace(folder, {
		profile = {

--~ 			columnHeight = 12,
			seenCount = 15,
			gemRarity = 3,
			gemLevel = 80,
			knownGems = 1,
			ignoreDragonEyes = true,
			ignoreStormjewels = true,
			
			--auctioneer stuff
			minProfitGold = 0,
			minProfitPercentage = 100,
			
			--New auction stuff.
			pricingAlgorithm = "",
			
			--ignore gems
			ignoreGems = {},
		},
	})

	
	
	local options = mainOptions.options
		
	
		
	options.args.display = {
		type = "group",
		name = DISPLAY,
		order = 3,
		
		get = function(info)
			local key = info[#info]
			return self.db.profile[key]
		end,
		set = function(info, v)
			local key = info[#info] 
			self.db.profile[key] = v
		end,
	
--~ 		disabled = function() return not core:IsEnabled() end,
	
		args = {
			showDisplay = {
				type = "execute",	order	= 2,
				name	= L.showDisplayName,
				desc	= L.showDisplayDesc,
				func = function(info, v)
					self.MainFrame:Show()
				end,
			},

			--[[
			--I couldn't seem to get this to work properly. On login it would have the correct height, but if I tried to update it later only new cells would have it.
			columnHeight = {
				type = "range",	order	= 8,
				name	= "Column Height",
				desc	= "xxx",
				min = 12,
				max = 20,
				step=1,
				set = function(info, v)
					local key = info[#info] 
					self.db.profile[key] = v
					self:UpdateNumColumns()
				end,
			},]]

			seenCount = {
				type = "range",	order	= 10,
				name	= "Show gems",
				desc	= L.seenCountDesc,
				min 	= 1,
				max 	= 200,
				step	= 1,
				width = "full",
			},
			
			gemRarity = {
				type = "range",	order	= 11,
				name	= L.gemRarityName,
				desc	= L.gemRarityDesc,
				min 	= 0,
				max 	= 3,
				step	= 1,
			},
			
			gemLevel = {
				type = "range",	order	= 12,
				name	= L.gemLevelName,
				desc	= L.gemLevelDesc,
				min 	= 60,
				max 	= 80,
				step	= 5,
			},
			knownGems = {
				type = "select",	order	= 13,
				name	= L.knownGemsName,
				desc	= L.knownGemsDesc,
				
				values = function()
					return {[0]=HIDE, [1]=L.include, [2]=L.only}
				end,
			},
			
			
			ignoreDragonEyes = {
				type = "toggle",	order	= 14,
				name	= L.ignoreDragonEyesName,
				desc	= L.ignoreDragonEyesDesc,
			},
			
			ignoreStormjewels = {
				type = "toggle",	order	= 15,
				name	= L.ignoreStormjewelsName,
				desc	= L.ignoreStormjewelsDesc,
			},
			


			
		}
	}
	
	--[[
	local ignoreGems = self.db.profile.ignoreGems
	
	local igOptions = options.args.display.args.ignoreGems
	
	igOptions.args = {
		Desc = {
			type = "description",
			name = "* This isn't working yet *",
			order = 1,
		},
					
		gemName = {
			type = "input",	order	= 3,
			name	= "Gem Name",
			desc	= "Input a gem name",
		},
		
		addGemName = {
			type = "execute",	order	= 4,
			name	= "Add gem to list",
			desc	= "xxx",
			func = function(info, v)
				--todo, add to table.
			end,
		},
		
		firstHeader = {
			type = "header",	order	= 9,
			name	= "",
		},
		---
		
	}
	
--~ 	for i, gemName in ipairs(ignoreGems) do 
--~ 		
--~ 	end
	]]
	
	
	
	LibStub("AceConfig-3.0"):RegisterOptionsTable(core.title, options ) --
end


function display:BuildPricingOptions()
	local options = mainOptions.options
	
	local algorithms, algorithmsIndex, defaultAlgorithmName = self:GetAlgorithms()
	
--~ 	Debug("BuildPricingOptions", defaultAlgorithmName)
	local values = {}
	for name, index in pairs(algorithmsIndex) do 
--~ 		Debug("algorithmsIndex", name, index)
		values[name] = name
	end
	
	if self.db.profile.pricingAlgorithm == "" then
		self.db.profile.pricingAlgorithm = defaultAlgorithmName
	end

	options.args.display.args.pricing = {
		type = "group",
		name = L.pricing,
		order = 1,
		args = {
--~ 			Desc = {
--~ 				type = "description",
--~ 				name = L.pricingDesc,
--~ 				order = 10,
--~ 			},
			
			pricingAlgorithm = {
				type = "select",	order	= 13,
				name	= L.pricingAlgorithmName,
				desc	= L.pricingAlgorithmDesc,
				values = values,
				
				set = function(info, v)
					local key = info[#info] 
					self.db.profile[key] = v
					self:FlushPriceData()
				end,
				
			},
			
			minProfitGold = {
				type = "range",	order	= 25,
				name	= L.minProfitGoldName,
				desc	= L.minProfitGoldDesc,
				min 	= 0,
				max 	= 100,
				step	= 5,
				disabled =  function() return not self:CanGetPrices() end,
			},
			minProfitPercentage = {
				type = "range",	order	= 26,
				name	= L.minProfitPercentageName,
				desc	= L.minProfitPercentageDesc,
				min 	= 100,
				max 	= 200,
				step	= 5,
				disabled =  function() return not self:CanGetPrices() end,
			},
			
		},
	}
	
	
	


	
	LibStub("AceConfig-3.0"):RegisterOptionsTable(core.title, options ) --
end